@@ -77,7 +77,6 @@ class CallbackModule(CallbackBase):
 
     def v2_runner_on_failed(self, result, ignore_errors=False):
 
-        delegated_vars = result._result.get('_ansible_delegated_vars', None)
         self._clean_results(result._result, result._task.action)
 
         if self._last_task_banner != result._task._uuid:
@@ -90,10 +89,10 @@ class CallbackModule(CallbackBase):
             self._process_items(result)
 
         else:
-            if delegated_vars:
+            if result._task.delegate_to:
                 if self._display.verbosity < 2 and self.get_option('show_task_path_on_failure'):
                     self._print_task_path(result._task)
-                self._display.display("fatal: [%s -> %s]: FAILED! => %s" % (result._host.get_name(), delegated_vars['ansible_host'],
+                self._display.display("fatal: [%s -> %s]: FAILED! => %s" % (result._host.get_name(), result._task.delegate_to,
                                                                             self._dump_results(result._result)),
                                       color=C.COLOR_ERROR, stderr=self.display_failed_stderr)
             else:
@@ -107,8 +106,6 @@ class CallbackModule(CallbackBase):
 
     def v2_runner_on_ok(self, result):
 
-        delegated_vars = result._result.get('_ansible_delegated_vars', None)
-
         if isinstance(result._task, TaskInclude):
             if self._last_task_banner != result._task._uuid:
                 self._print_task_banner(result._task)
@@ -117,8 +114,8 @@ class CallbackModule(CallbackBase):
             if self._last_task_banner != result._task._uuid:
                 self._print_task_banner(result._task)
 
-            if delegated_vars:
-                msg = "changed: [%s -> %s]" % (result._host.get_name(), delegated_vars['ansible_host'])
+            if result._task.delegate_to:
+                msg = "changed: [%s -> %s]" % (result._host.get_name(), result._task.delegate_to)
             else:
                 msg = "changed: [%s]" % result._host.get_name()
             color = C.COLOR_CHANGED
@@ -129,8 +126,8 @@ class CallbackModule(CallbackBase):
             if self._last_task_banner != result._task._uuid:
                 self._print_task_banner(result._task)
 
-            if delegated_vars:
-                msg = "ok: [%s -> %s]" % (result._host.get_name(), delegated_vars['ansible_host'])
+            if result._task.delegate_to:
+                msg = "ok: [%s -> %s]" % (result._host.get_name(), result._task.delegate_to)
             else:
                 msg = "ok: [%s]" % result._host.get_name()
             color = C.COLOR_OK
@@ -167,9 +164,8 @@ class CallbackModule(CallbackBase):
         if self._last_task_banner != result._task._uuid:
             self._print_task_banner(result._task)
 
-        delegated_vars = result._result.get('_ansible_delegated_vars', None)
-        if delegated_vars:
-            msg = "fatal: [%s -> %s]: UNREACHABLE! => %s" % (result._host.get_name(), delegated_vars['ansible_host'], self._dump_results(result._result))
+        if result._task.delegate_to:
+            msg = "fatal: [%s -> %s]: UNREACHABLE! => %s" % (result._host.get_name(), result._task.delegate_to, self._dump_results(result._result))
         else:
             msg = "fatal: [%s]: UNREACHABLE! => %s" % (result._host.get_name(), self._dump_results(result._result))
         self._display.display(msg, color=C.COLOR_UNREACHABLE, stderr=self.display_failed_stderr)
@@ -278,7 +274,6 @@ class CallbackModule(CallbackBase):
 
     def v2_runner_item_on_ok(self, result):
 
-        delegated_vars = result._result.get('_ansible_delegated_vars', None)
         if isinstance(result._task, TaskInclude):
             return
         elif result._result.get('changed', False):
@@ -297,8 +292,8 @@ class CallbackModule(CallbackBase):
             msg = 'ok'
             color = C.COLOR_OK
 
-        if delegated_vars:
-            msg += ": [%s -> %s]" % (result._host.get_name(), delegated_vars['ansible_host'])
+        if result._task.delegate_to:
+            msg += ": [%s -> %s]" % (result._host.get_name(), result._task.delegate_to)
         else:
             msg += ": [%s]" % result._host.get_name()
 
@@ -313,13 +308,12 @@ class CallbackModule(CallbackBase):
         if self._last_task_banner != result._task._uuid:
             self._print_task_banner(result._task)
 
-        delegated_vars = result._result.get('_ansible_delegated_vars', None)
         self._clean_results(result._result, result._task.action)
         self._handle_exception(result._result)
 
         msg = "failed: "
-        if delegated_vars:
-            msg += "[%s -> %s]" % (result._host.get_name(), delegated_vars['ansible_host'])
+        if result._task.delegate_to:
+            msg += "[%s -> %s]" % (result._host.get_name(), result._task.delegate_to)
         else:
             msg += "[%s]" % (result._host.get_name())
 
